.. _install:

Installation
============

PyPI
----

bitcash is distributed on `PyPI`_ as a universal wheel and is available on Linux/macOS
and Windows and supports Python 3.5+ and PyPy3.5-v5.7.1+. ``pip`` >= 8.1.2 is required.

.. code-block:: bash

    $ pip install bitcash

Source Code
-----------

bitcash is hosted by GitHub `here`_, where it is actively developed.

You can clone it like this:

.. code-block:: bash

    $ git clone git://github.com/sporestack/bitcash.git

.. _PyPI: https://pypi.org/project/bitcash
.. _here: https://github.com/sporestack/bitcash
